# axonius_api_client

[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
[![Made With Python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
[![PyPi package](https://badge.fury.io/py/axonius-api-client.svg)](https://pypi.org/project/axonius-api-client/)
[![GitHub Repository](https://badge.fury.io/gh/Axonius%2Faxonius_api_client.svg)](https://github.com/Axonius/axonius_api_client)
[![Documentation Status](https://readthedocs.org/projects/axonius-api-client/badge/?version=latest)](https://axonius-api-client.readthedocs.io/en/latest/?badge=latest)
[![Downloads](https://pepy.tech/badge/axonius-api-client)](https://pepy.tech/project/axonius-api-client)

axonius-api-client is an API client for [Axonius](https://axonius.com) that provides:

* A fully modeled python API library that makes using the Axonius REST API easy.
* A powerful command line interface that exposes most of the functionality of the
  underlying python library.

Resources:

* [Documentation](https://axonius-api-client.readthedocs.io/)
* [PyPi package listing](https://pypi.org/project/axonius-api-client/)
* [GitHub repository](https://github.com/Axonius/axonius_api_client)
